@@ -14,7 +14,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 from oslo_config import cfg
-from oslo_log import log as logging
 
 from designate import utils
 from designate import dnsutils
@@ -23,11 +22,11 @@ from designate.agent import handler
 from designate.backend import agent_backend
 
 
-LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
 class Service(service.DNSService, service.Service):
+
     def __init__(self, threads=None):
         super(Service, self).__init__(threads=threads)
 
