@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -37,5 +37,5 @@ class NameServersController(rest.RestController):
         return {
             "nameservers": DesignateAdapter.render(
                 'API_v2',
-                self.central_api.get_domain_servers(context, zone_id),
+                self.central_api.get_zone_ns_records(context, zone_id),
                 request=request)}
