@@ -1,6 +1,6 @@
 # Copyright 2012 Hewlett-Packard Development Company, L.P. All Rights Reserved.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -28,7 +28,7 @@ def factory(global_config, **local_conf):
 
     def _host_header_links():
         del versions[:]
-        host_url = flask.request.host_url
+        host_url = flask.request.host_url.rstrip('/')
         _version('v1', 'DEPRECATED', host_url)
         _version('v2', 'CURRENT', host_url)
 
