@@ -2,7 +2,7 @@
 # Copyright 2014 Red Hat, Inc.
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -17,6 +17,7 @@
 # under the License.
 
 import math
+import time
 import uuid
 
 from oslo_config import cfg
@@ -32,7 +33,6 @@ LOG = log.getLogger(__name__)
 
 OPTS = [
     cfg.StrOpt('backend_url',
-               default=None,
                help='The backend URL to use for distributed coordination. If '
                     'unset services that need coordination will function as '
                     'a standalone service.'),
@@ -75,17 +75,22 @@ class CoordinationMixin(object):
             msg = _LW("No coordination backend configured, distributed "
                       "coordination functionality will be disabled. "
                       "Please configure a coordination backend.")
-            LOG.warn(msg)
+            LOG.warning(msg)
 
         super(CoordinationMixin, self).start()
 
         if self._coordinator is not None:
-            self._coordinator.start()
+            while not self._coordination_started:
+                try:
+                    self._coordinator.start()
+                    self._coordinator.create_group(self.service_name)
+                    self._coordinator.join_group(self.service_name)
+                    self._coordination_started = True
 
-            self._coordinator.create_group(self.service_name)
-            self._coordinator.join_group(self.service_name)
-
-            self._coordination_started = True
+                except Exception:
+                    LOG.warning(_LW("Failed to start Coordinator:"),
+                             exc_info=True)
+                    time.sleep(15)
 
     def stop(self):
         if self._coordinator is not None:
@@ -135,8 +140,11 @@ class Partitioner(object):
         get_members_req = self._coordinator.get_members(group_id)
         try:
             return get_members_req.get()
-        except tooz.ToozError:
-            self.join_group(group_id)
+
+        except tooz.coordination.GroupNotCreated:
+            LOG.error(_LE('Attempting to partition over a non-existent group: '
+                          '%s'), self._group_id)
+            raise
 
     def _on_group_change(self, event):
         LOG.debug("Received member change %s" % event)
