@@ -91,11 +91,21 @@ class NeutronCommunicationFailure(CommunicationFailure):
     error_type = 'neutron_communication_failure'
 
 
+class NoFiltersConfigured(ConfigurationError):
+    error_code = 500
+    error_type = 'no_filters_configured'
+
+
 class NoServersConfigured(ConfigurationError):
     error_code = 500
     error_type = 'no_servers_configured'
 
 
+class MultiplePoolsFound(ConfigurationError):
+    error_code = 500
+    error_type = 'multiple_pools_found'
+
+
 class NoPoolTargetsConfigured(ConfigurationError):
     error_code = 500
     error_type = 'no_pool_targets_configured'
@@ -104,6 +114,7 @@ class NoPoolTargetsConfigured(ConfigurationError):
 class OverQuota(Base):
     error_code = 413
     error_type = 'over_quota'
+    expected = True
 
 
 class QuotaResourceUnknown(Base):
@@ -179,20 +190,22 @@ class UnsupportedContentType(BadRequest):
     error_type = 'unsupported_content_type'
 
 
-class InvalidDomainName(Base):
+class InvalidZoneName(Base):
     error_code = 400
-    error_type = 'invalid_domain_name'
+    error_type = 'invalid_zone_name'
     expected = True
 
 
 class InvalidRecordSetName(Base):
     error_code = 400
     error_type = 'invalid_recordset_name'
+    expected = True
 
 
 class InvalidRecordSetLocation(Base):
     error_code = 400
     error_type = 'invalid_recordset_location'
+    expected = True
 
 
 class InvaildZoneTransfer(Base):
@@ -205,9 +218,9 @@ class InvalidTTL(Base):
     error_type = 'invalid_ttl'
 
 
-class DomainHasSubdomain(Base):
+class ZoneHasSubZone(Base):
     error_code = 400
-    error_type = 'domain_has_subdomain'
+    error_type = 'zone_has_sub_zone'
 
 
 class Forbidden(Base):
@@ -216,11 +229,11 @@ class Forbidden(Base):
     expected = True
 
 
-class IllegalChildDomain(Forbidden):
+class IllegalChildZone(Forbidden):
     error_type = 'illegal_child'
 
 
-class IllegalParentDomain(Forbidden):
+class IllegalParentZone(Forbidden):
     error_type = 'illegal_parent'
 
 
@@ -246,8 +259,8 @@ class DuplicateTsigKey(Duplicate):
     error_type = 'duplicate_tsigkey'
 
 
-class DuplicateDomain(Duplicate):
-    error_type = 'duplicate_domain'
+class DuplicateZone(Duplicate):
+    error_type = 'duplicate_zone'
 
 
 class DuplicateTld(Duplicate):
@@ -278,14 +291,30 @@ class DuplicatePoolAttribute(Duplicate):
     error_type = 'duplicate_pool_attribute'
 
 
-class DuplicateDomainAttribute(Duplicate):
-    error_type = 'duplicate_domain_attribute'
-
-
 class DuplicatePoolNsRecord(Duplicate):
     error_type = 'duplicate_pool_ns_record'
 
 
+class DuplicatePoolNameserver(Duplicate):
+    error_type = 'duplicate_pool_nameserver'
+
+
+class DuplicatePoolTarget(Duplicate):
+    error_type = 'duplicate_pool_target'
+
+
+class DuplicatePoolTargetOption(Duplicate):
+    error_type = 'duplicate_pool_target_option'
+
+
+class DuplicatePoolTargetMaster(Duplicate):
+    error_type = 'duplicate_pool_target_master'
+
+
+class DuplicatePoolAlsoNotify(Duplicate):
+    error_type = 'duplicate_pool_also_notify'
+
+
 class DuplicateZoneImport(Duplicate):
     error_type = 'duplicate_zone_import'
 
@@ -308,6 +337,14 @@ class DuplicateZoneTransferAccept(Duplicate):
     error_type = 'duplicate_zone_transfer_accept'
 
 
+class DuplicateZoneAttribute(Duplicate):
+    error_type = 'duplicate_zone_attribute'
+
+
+class DuplicateZoneMaster(Duplicate):
+    error_type = 'duplicate_zone_attribute'
+
+
 class NotFound(Base):
     expected = True
     error_code = 404
@@ -330,16 +367,16 @@ class BlacklistNotFound(NotFound):
     error_type = 'blacklist_not_found'
 
 
-class DomainNotFound(NotFound):
-    error_type = 'domain_not_found'
+class ZoneNotFound(NotFound):
+    error_type = 'zone_not_found'
 
 
-class DomainMasterNotFound(NotFound):
-    error_type = 'domain_master_not_found'
+class ZoneMasterNotFound(NotFound):
+    error_type = 'zone_master_not_found'
 
 
-class DomainAttributeNotFound(NotFound):
-    error_type = 'domain_attribute_not_found'
+class ZoneAttributeNotFound(NotFound):
+    error_type = 'zone_attribute_not_found'
 
 
 class TldNotFound(NotFound):
@@ -366,6 +403,10 @@ class PoolNotFound(NotFound):
     error_type = 'pool_not_found'
 
 
+class NoValidPoolFound(NotFound):
+    error_type = 'no_valid_pool_found'
+
+
 class PoolAttributeNotFound(NotFound):
     error_type = 'pool_attribute_not_found'
 
@@ -374,6 +415,26 @@ class PoolNsRecordNotFound(NotFound):
     error_type = 'pool_ns_record_not_found'
 
 
+class PoolNameserverNotFound(NotFound):
+    error_type = 'pool_nameserver_not_found'
+
+
+class PoolTargetNotFound(NotFound):
+    error_type = 'pool_target_not_found'
+
+
+class PoolTargetOptionNotFound(NotFound):
+    error_type = 'pool_target_option_not_found'
+
+
+class PoolTargetMasterNotFound(NotFound):
+    error_type = 'pool_target_master_not_found'
+
+
+class PoolAlsoNotifyNotFound(NotFound):
+    error_type = 'pool_also_notify_not_found'
+
+
 class ZoneTransferRequestNotFound(NotFound):
     error_type = 'zone_transfer_request_not_found'
 
