@@ -12,7 +12,9 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+
 import time
+import socket
 
 import eventlet
 import dns
@@ -40,11 +42,11 @@ class NotifyEndpoint(base.BaseEndpoint):
     RPC_API_VERSION = '2.0'
     RPC_API_NAMESPACE = 'notify'
 
-    def notify_zone_changed(self, context, domain, host, port, timeout,
+    def notify_zone_changed(self, context, zone, host, port, timeout,
                             retry_interval, max_retries, delay):
         """
         :param context: The user context.
-        :param domain: The designate domain object.  This contains the domain
+        :param zone: The designate zone object.  This contains the zone
             name.
         :param host: A notify is sent to this host.
         :param port: A notify is sent to this port.
@@ -61,15 +63,17 @@ class NotifyEndpoint(base.BaseEndpoint):
         """
         time.sleep(delay)
         return self._make_and_send_dns_message(
-            domain, host, port, timeout, retry_interval, max_retries,
+            zone, host, port, timeout, retry_interval, max_retries,
             notify=True)
 
-    def poll_for_serial_number(self, context, domain, nameserver, timeout,
+    def poll_for_serial_number(self, context, zone, nameserver, timeout,
                                retry_interval, max_retries, delay):
-        """
+        """Get the serial number of a zone on a resolver, then call update_status
+        on Pool Manager to update the zone status.
+
         :param context: The user context.
-        :param domain: The designate domain object.  This contains the domain
-            name. domain.serial = expected_serial
+        :param zone: The designate zone object.  This contains the zone
+            name. zone.serial = expected_serial
         :param nameserver: Destination for the poll
         :param timeout: The time (in seconds) to wait for a SOA response from
             nameserver.
@@ -78,20 +82,20 @@ class NotifyEndpoint(base.BaseEndpoint):
             an expected serial number. After this many retries, mindns returns
             an ERROR.
         :param delay: The time to wait before sending the first request.
-        :return: The pool manager is informed of the status with update_status.
+        :return: None
         """
         (status, actual_serial, retries) = self.get_serial_number(
-            context, domain, nameserver.host, nameserver.port, timeout,
+            context, zone, nameserver.host, nameserver.port, timeout,
             retry_interval, max_retries, delay)
         self.pool_manager_api.update_status(
-            context, domain, nameserver, status, actual_serial)
+            context, zone, nameserver, status, actual_serial)
 
-    def get_serial_number(self, context, domain, host, port, timeout,
+    def get_serial_number(self, context, zone, host, port, timeout,
                           retry_interval, max_retries, delay):
         """
         :param context: The user context.
-        :param domain: The designate domain object.  This contains the domain
-            name. domain.serial = expected_serial
+        :param zone: The designate zone object.  This contains the zone
+            name. zone.serial = expected_serial
         :param host: A notify is sent to this host.
         :param port: A notify is sent to this port.
         :param timeout: The time (in seconds) to wait for a SOA response from
@@ -111,49 +115,60 @@ class NotifyEndpoint(base.BaseEndpoint):
         """
         actual_serial = None
         status = 'ERROR'
-        retries = max_retries
+        retries_left = max_retries
         time.sleep(delay)
-        while (True):
-            (response, retry) = self._make_and_send_dns_message(
-                domain, host, port, timeout, retry_interval, retries)
-            if response and response.rcode() in (
-                    dns.rcode.NXDOMAIN, dns.rcode.REFUSED, dns.rcode.SERVFAIL):
-                status = 'NO_DOMAIN'
+        while True:
+            response, retry_cnt = self._make_and_send_dns_message(
+                zone, host, port, timeout, retry_interval, retries_left)
+
+            if response and (response.rcode() in (
+                    dns.rcode.NXDOMAIN, dns.rcode.REFUSED, dns.rcode.SERVFAIL)
+                    or not bool(response.answer)):
+                status = 'NO_ZONE'
+                if zone.serial == 0 and zone.action in ('DELETE', 'NONE'):
+                    actual_serial = 0
+                    break  # Zone not expected to exist
+
             elif response and len(response.answer) == 1 \
-                    and str(response.answer[0].name) == str(domain.name) \
+                    and str(response.answer[0].name) == str(zone.name) \
                     and response.answer[0].rdclass == dns.rdataclass.IN \
                     and response.answer[0].rdtype == dns.rdatatype.SOA:
                 # parse the SOA response and get the serial number
                 rrset = response.answer[0]
                 actual_serial = rrset.to_rdataset().items[0].serial
 
-            if actual_serial is None or actual_serial < domain.serial:
-                # TODO(vinod): Account for serial number wrap around.
-                retries = retries - retry
-                LOG.warn(_LW("Got lower serial for '%(zone)s' to '%(host)s:"
-                             "%(port)s'. Expected:'%(es)d'. Got:'%(as)s'."
-                             "Retries left='%(retries)d'") %
-                         {'zone': domain.name, 'host': host,
-                          'port': port, 'es': domain.serial,
-                          'as': actual_serial, 'retries': retries})
-                if retries > 0:
-                    # retry again
-                    time.sleep(retry_interval)
-                    continue
-                else:
-                    break
-            else:
+            # TODO(vinod): Account for serial number wrap around. Unix
+            # timestamps are used where Designate is primary, but secondary
+            # zones use different values.
+            if actual_serial is not None and actual_serial >= zone.serial:
                 # Everything looks good at this point. Return SUCCESS.
                 status = 'SUCCESS'
                 break
 
-        # Return retries for testing purposes.
-        return (status, actual_serial, retries)
+            retries_left -= retry_cnt
+            msg = _LW("Got lower serial for '%(zone)s' to '%(host)s:"
+                      "%(port)s'. Expected:'%(es)d'. Got:'%(as)s'."
+                      "Retries left='%(retries)d'") % {
+                          'zone': zone.name, 'host': host, 'port': port,
+                          'es': zone.serial, 'as': actual_serial,
+                          'retries': retries_left}
 
-    def _make_and_send_dns_message(self, domain, host, port, timeout,
+            if not retries_left:
+                # return with error
+                LOG.warning(msg)
+                break
+
+            LOG.debug(msg)
+            # retry again
+            time.sleep(retry_interval)
+
+        # Return retries_left for testing purposes.
+        return status, actual_serial, retries_left
+
+    def _make_and_send_dns_message(self, zone, host, port, timeout,
                                    retry_interval, max_retries, notify=False):
         """
-        :param domain: The designate domain object.  This contains the domain
+        :param zone: The designate zone object.  This contains the zone
             name.
         :param host: The destination host for the dns message.
         :param port: The destination port for the dns message.
@@ -168,65 +183,92 @@ class NotifyEndpoint(base.BaseEndpoint):
             response is the response on success or None on failure.
             current_retry is the current retry number
         """
-        dns_message = self._make_dns_message(domain.name, notify=notify)
+        dns_message = self._make_dns_message(zone.name, notify=notify)
 
         retry = 0
         response = None
 
         while retry < max_retries:
-            retry = retry + 1
+            retry += 1
             LOG.info(_LI("Sending '%(msg)s' for '%(zone)s' to '%(server)s:"
-                         "%(port)d'.") %
+                         "%(port)d'."),
                      {'msg': 'NOTIFY' if notify else 'SOA',
-                      'zone': domain.name, 'server': host,
+                      'zone': zone.name, 'server': host,
                       'port': port})
-            response = self._send_dns_message(
-                dns_message, host, port, timeout)
+            try:
+                response = self._send_dns_message(dns_message, host, port,
+                                                  timeout)
 
-            if isinstance(response, dns.exception.Timeout):
-                LOG.warn(_LW("Got Timeout while trying to send '%(msg)s' for "
-                             "'%(zone)s' to '%(server)s:%(port)d'. Timeout="
-                             "'%(timeout)d' seconds. Retry='%(retry)d'") %
-                         {'msg': 'NOTIFY' if notify else 'SOA',
-                          'zone': domain.name, 'server': host,
-                          'port': port, 'timeout': timeout,
-                          'retry': retry})
-                response = None
+            except socket.error as e:
+                if e.errno != socket.errno.EAGAIN:
+                    raise  # unknown error, let it traceback
+
+                # Initial workaround for bug #1558096
+                LOG.info(
+                    _LW("Got EAGAIN while trying to send '%(msg)s' for "
+                        "'%(zone)s' to '%(server)s:%(port)d'. Timeout="
+                        "'%(timeout)d' seconds. Retry='%(retry)d'") %
+                    {'msg': 'NOTIFY' if notify else 'SOA',
+                     'zone': zone.name, 'server': host,
+                     'port': port, 'timeout': timeout,
+                     'retry': retry})
+                # retry sending the message
+                time.sleep(retry_interval)
+                continue
+
+            except dns.exception.Timeout:
+                LOG.warning(
+                    _LW("Got Timeout while trying to send '%(msg)s' for "
+                        "'%(zone)s' to '%(server)s:%(port)d'. Timeout="
+                        "'%(timeout)d' seconds. Retry='%(retry)d'") %
+                    {'msg': 'NOTIFY' if notify else 'SOA',
+                     'zone': zone.name, 'server': host,
+                     'port': port, 'timeout': timeout,
+                     'retry': retry})
                 # retry sending the message if we get a Timeout.
                 time.sleep(retry_interval)
                 continue
-            elif isinstance(response, dns_query.BadResponse):
-                LOG.warn(_LW("Got BadResponse while trying to send '%(msg)s' "
-                             "for '%(zone)s' to '%(server)s:%(port)d'. Timeout"
-                             "='%(timeout)d' seconds. Retry='%(retry)d'") %
-                         {'msg': 'NOTIFY' if notify else 'SOA',
-                          'zone': domain.name, 'server': host,
-                          'port': port, 'timeout': timeout,
-                          'retry': retry})
-                response = None
-                break
-            # Check that we actually got a NOERROR in the rcode and and an
-            # authoritative answer
-            elif response.rcode() in (dns.rcode.NXDOMAIN, dns.rcode.REFUSED,
-                                      dns.rcode.SERVFAIL):
-                LOG.info(_LI("%(zone)s not found on %(server)s:%(port)d") %
-                         {'zone': domain.name, 'server': host,
-                         'port': port})
-                break
-            elif not (response.flags & dns.flags.AA) or dns.rcode.from_flags(
-                    response.flags, response.ednsflags) != dns.rcode.NOERROR:
-                LOG.warn(_LW("Failed to get expected response while trying to "
-                             "send '%(msg)s' for '%(zone)s' to '%(server)s:"
-                             "%(port)d'.\nResponse message:\n%(resp)s\n") %
-                         {'msg': 'NOTIFY' if notify else 'SOA',
-                          'zone': domain.name, 'server': host,
-                          'port': port, 'resp': str(response)})
-                response = None
-                break
-            else:
-                break
 
-        return (response, retry)
+            except dns_query.BadResponse:
+                LOG.warning(
+                    _LW("Got BadResponse while trying to send '%(msg)s' "
+                        "for '%(zone)s' to '%(server)s:%(port)d'. Timeout"
+                        "='%(timeout)d' seconds. Retry='%(retry)d'") %
+                    {'msg': 'NOTIFY' if notify else 'SOA',
+                     'zone': zone.name, 'server': host,
+                     'port': port, 'timeout': timeout,
+                     'retry': retry})
+                break  # no retries after BadResponse
+
+            # either we have a good response or an error that we don't want to
+            # recover by retrying
+            break
+
+        # Check that we actually got a NOERROR in the rcode and and an
+        # authoritative answer
+        if response is None:
+            pass
+
+        elif (response.rcode() in
+                (dns.rcode.NXDOMAIN, dns.rcode.REFUSED,
+                    dns.rcode.SERVFAIL)) or \
+                (response.rcode() == dns.rcode.NOERROR and
+                    not bool(response.answer)):
+            LOG.info(_LI("%(zone)s not found on %(server)s:%(port)d") %
+                     {'zone': zone.name, 'server': host, 'port': port})
+
+        elif not (response.flags & dns.flags.AA) or dns.rcode.from_flags(
+                response.flags, response.ednsflags) != dns.rcode.NOERROR:
+            LOG.warning(
+                _LW("Failed to get expected response while trying to "
+                    "send '%(msg)s' for '%(zone)s' to '%(server)s:"
+                    "%(port)d'.\nResponse message:\n%(resp)s\n") %
+                {'msg': 'NOTIFY' if notify else 'SOA',
+                    'zone': zone.name, 'server': host,
+                    'port': port, 'resp': str(response)})
+            response = None
+
+        return response, retry
 
     def _make_dns_message(self, zone_name, notify=False):
         """
@@ -255,17 +297,12 @@ class NotifyEndpoint(base.BaseEndpoint):
         :param host: The destination ip of dns_message.
         :param port: The destination port of dns_message.
         :param timeout: The timeout in seconds to wait for a response.
-        :return: response or dns.exception.Timeout or dns_query.BadResponse
+        :return: response
         """
-        try:
-            if not CONF['service:mdns'].all_tcp:
-                response = dns_query.udp(
-                    dns_message, host, port=port, timeout=timeout)
-            else:
-                response = dns_query.tcp(
-                    dns_message, host, port=port, timeout=timeout)
-            return response
-        except dns.exception.Timeout as timeout:
-            return timeout
-        except dns_query.BadResponse as badResponse:
-            return badResponse
+        if not CONF['service:mdns'].all_tcp:
+            response = dns_query.udp(
+                dns_message, host, port=port, timeout=timeout)
+        else:
+            response = dns_query.tcp(
+                dns_message, host, port=port, timeout=timeout)
+        return response
