@@ -1,6 +1,6 @@
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -29,11 +29,15 @@ CONF = cfg.CONF
 
 
 class Service(service.DNSService, service.RPCService, service.Service):
-    def __init__(self, threads=None):
-        super(Service, self).__init__(threads=threads)
 
-        # Get a storage connection
-        self.storage = storage.get_storage(CONF['service:mdns'].storage_driver)
+    @property
+    def storage(self):
+        if not hasattr(self, '_storage'):
+            # Get a storage connection
+            self._storage = storage.get_storage(
+                CONF['service:mdns'].storage_driver
+            )
+        return self._storage
 
     @property
     def service_name(self):
