@@ -110,21 +110,21 @@ class NeutronNetworkAPI(NetworkAPI):
 
         def _call(endpoint, region, *args, **kw):
             client = get_client(context, endpoint=endpoint)
-            LOG.debug("Attempting to fetch FloatingIPs from %s @ %s" %
-                      (endpoint, region))
+            LOG.debug("Attempting to fetch FloatingIPs from %s @ %s",
+                      endpoint, region)
             try:
                 fips = client.list_floatingips(*args, **kw)
             except neutron_exceptions.Unauthorized as e:
                 # NOTE: 401 might be that the user doesn't have neutron
                 # activated in a particular region, we'll just log the failure
                 # and go on with our lives.
-                LOG.warn(_LW("Calling Neutron resulted in a 401, "
+                LOG.warning(_LW("Calling Neutron resulted in a 401, "
                              "please investigate."))
                 LOG.exception(e)
                 return
             except Exception as e:
                 LOG.error(_LE('Failed calling Neutron '
-                              '%(region)s - %(endpoint)s') %
+                              '%(region)s - %(endpoint)s'),
                           {'region': region, 'endpoint': endpoint})
                 LOG.exception(e)
                 failed.append((e, endpoint, region))
@@ -137,8 +137,8 @@ class NeutronNetworkAPI(NetworkAPI):
                     'region': region
                 })
 
-            LOG.debug("Added %i FloatingIPs from %s @ %s" %
-                      (len(data), endpoint, region))
+            LOG.debug("Added %i FloatingIPs from %s @ %s",
+                      len(data), endpoint, region)
 
         for endpoint, region in endpoints:
             tg.add_thread(_call, endpoint, region,
