@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -24,12 +24,12 @@ LOG = logging.getLogger(__name__)
 cfg.CONF.register_opts([
     cfg.StrOpt('quota-driver', default='storage', help='Quota driver to use'),
 
-    cfg.IntOpt('quota-domains', default=10,
-               help='Number of domains allowed per tenant'),
-    cfg.IntOpt('quota-domain-recordsets', default=500,
-               help='Number of recordsets allowed per domain'),
-    cfg.IntOpt('quota-domain-records', default=500,
-               help='Number of records allowed per domain'),
+    cfg.IntOpt('quota-zones', default=10,
+               help='Number of zones allowed per tenant'),
+    cfg.IntOpt('quota-zone-recordsets', default=500,
+               help='Number of recordsets allowed per zone'),
+    cfg.IntOpt('quota-zone-records', default=500,
+               help='Number of records allowed per zone'),
     cfg.IntOpt('quota-recordset-records', default=20,
                help='Number of records allowed per recordset'),
     cfg.IntOpt('quota-api-export-size', default=1000,
