@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -27,7 +27,7 @@ LOG = logging.getLogger(__name__)
 #              "\Z", rather than simply "$" to ensure a string with a
 #              trailing newline is NOT matched. See bug #1471158.
 
-RE_DOMAINNAME = r'^(?!.{255,})(?:(?!\-)[A-Za-z0-9_\-]{1,63}(?<!\-)\.)+\Z'
+RE_ZONENAME = r'^(?!.{255,})(?:(?!\-)[A-Za-z0-9_\-]{1,63}(?<!\-)\.)+\Z'
 RE_HOSTNAME = r'^(?!.{255,})(?:(?:^\*|(?!\-)[A-Za-z0-9_\-]{1,63})(?<!\-)\.)+\Z'
 
 RE_SRV_HOST_NAME = r'^(?:(?!\-)(?:\_[A-Za-z0-9_\-]{1,63}\.){2})(?!.{255,})' \
@@ -108,7 +108,7 @@ def is_ns_hostname(instance):
         return True
 
     # BIND doesn't like *.host.com. see bug #1533299
-    if not re.match(RE_DOMAINNAME, instance):
+    if not re.match(RE_ZONENAME, instance):
         return False
 
     return True
@@ -120,7 +120,7 @@ def is_ip_or_host(instance):
     if not isinstance(instance, compat.str_types):
         return True
 
-    if not re.match(RE_DOMAINNAME, instance)\
+    if not re.match(RE_ZONENAME, instance)\
             and not is_ipv4(instance)\
             and not is_ipv6(instance):
         return False
@@ -130,11 +130,13 @@ def is_ip_or_host(instance):
 
 @draft3_format_checker.checks("domain-name")
 @draft4_format_checker.checks("domainname")
-def is_domainname(instance):
+@draft3_format_checker.checks("zone-name")
+@draft4_format_checker.checks("zonename")
+def is_zonename(instance):
     if not isinstance(instance, compat.str_types):
         return True
 
-    if not re.match(RE_DOMAINNAME, instance):
+    if not re.match(RE_ZONENAME, instance):
         return False
 
     return True
@@ -186,7 +188,7 @@ def is_email(instance):
 
     rname = instance.replace('@', '.', 1)
 
-    if not re.match(RE_DOMAINNAME, "%s." % rname):
+    if not re.match(RE_ZONENAME, "%s." % rname):
         return False
 
     return True
@@ -218,7 +220,7 @@ def is_uuid(instance):
 @draft3_format_checker.checks("floating-ip-id")
 @draft4_format_checker.checks("floating-ip-id")
 def is_floating_ip_id(instance):
-    # TODO(kiall): Apparantly, this is used in exactly zero places outside the
+    # TODO(kiall): Apparently, this is used in exactly zero places outside the
     #              tests. Determine if we should remove this code...
     if not isinstance(instance, compat.str_types):
         return True
