@@ -28,7 +28,6 @@ import eventlet.debug
 import oslo_messaging as messaging
 from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_log import loggers
 from oslo_service import service
 from oslo_service import sslutils
 
@@ -87,12 +86,12 @@ class Service(service.Service):
     def start(self):
         super(Service, self).start()
 
-        LOG.info(_('Starting %(name)s service (version: %(version)s)') %
+        LOG.info(_('Starting %(name)s service (version: %(version)s)'),
                  {'name': self.service_name,
                   'version': version.version_info.version_string()})
 
     def stop(self):
-        LOG.info(_('Stopping %(name)s service') % {'name': self.service_name})
+        LOG.info(_('Stopping %(name)s service'), {'name': self.service_name})
 
         super(Service, self).stop()
 
@@ -189,7 +188,7 @@ class WSGIService(object):
         eventlet.wsgi.server(self._wsgi_sock,
                              self._wsgi_application,
                              custom_pool=self.tg.pool,
-                             log=loggers.WritableLogger(logger))
+                             log=logger)
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -269,18 +268,19 @@ class DNSService(object):
             # ensure no exceptions are generated from within.
             except socket.timeout:
                 client.close()
-                LOG.warn(_LW("TCP Timeout from: %(host)s:%(port)d") %
-                         {'host': addr[0], 'port': addr[1]})
+                LOG.warning(_LW("TCP Timeout from: %(host)s:%(port)d") %
+                            {'host': addr[0], 'port': addr[1]})
 
             except socket.error as e:
                 client.close()
                 errname = errno.errorcode[e.args[0]]
-                LOG.warn(_LW("Socket error %(err)s from: %(host)s:%(port)d") %
-                         {'host': addr[0], 'port': addr[1], 'err': errname})
+                LOG.warning(
+                    _LW("Socket error %(err)s from: %(host)s:%(port)d") %
+                    {'host': addr[0], 'port': addr[1], 'err': errname})
 
             except struct.error:
                 client.close()
-                LOG.warn(_LW("Invalid packet from: %(host)s:%(port)d") %
+                LOG.warning(_LW("Invalid packet from: %(host)s:%(port)d") %
                          {'host': addr[0], 'port': addr[1]})
 
             except Exception:
@@ -311,8 +311,9 @@ class DNSService(object):
 
             except socket.error as e:
                 errname = errno.errorcode[e.args[0]]
-                LOG.warn(_LW("Socket error %(err)s from: %(host)s:%(port)d") %
-                         {'host': addr[0], 'port': addr[1], 'err': errname})
+                LOG.warning(
+                    _LW("Socket error %(err)s from: %(host)s:%(port)d") %
+                    {'host': addr[0], 'port': addr[1], 'err': errname})
 
             except Exception:
                 LOG.exception(_LE("Unknown exception handling UDP request "
