@@ -1,6 +1,6 @@
 # Copyright 2012-2014 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -36,14 +36,16 @@ TSIG_SCOPES = ['POOL', 'ZONE']
 POOL_PROVISIONERS = ['UNMANAGED']
 ACTIONS = ['CREATE', 'DELETE', 'UPDATE', 'NONE']
 
-ZONE_ATTRIBUTE_KEYS = ('master',)
-
 ZONE_TYPES = ('PRIMARY', 'SECONDARY',)
 ZONE_TASK_TYPES = ['IMPORT', 'EXPORT']
 
 
 metadata = MetaData()
 
+# TODO(Federico) some default column values are not needed because we
+# explicitely set the value on record insertion. Having default values could
+# hide bugs.
+
 
 def default_shard(context, id_col):
     return int(context.current_parameters[id_col][0:3], 16)
@@ -51,13 +53,13 @@ def default_shard(context, id_col):
 
 quotas = Table('quotas', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
 
     Column('tenant_id', String(36), default=None, nullable=True),
     Column('resource', String(32), nullable=False),
-    Column('hard_limit', Integer(), nullable=False),
+    Column('hard_limit', Integer, nullable=False),
 
     mysql_engine='InnoDB',
     mysql_charset='utf8',
@@ -65,7 +67,7 @@ quotas = Table('quotas', metadata,
 
 tlds = Table('tlds', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
 
@@ -76,16 +78,16 @@ tlds = Table('tlds', metadata,
     mysql_charset='utf8',
 )
 
-domains = Table('domains', metadata,
+zones = Table('zones', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
 
     Column('deleted', CHAR(32), nullable=False, default='0',
            server_default='0'),
     Column('deleted_at', DateTime, nullable=True, default=None),
-    Column('shard', SmallInteger(), nullable=False,
+    Column('shard', SmallInteger, nullable=False,
            default=lambda ctxt: default_shard(ctxt, 'id')),
 
     Column('tenant_id', String(36), default=None, nullable=True),
@@ -96,7 +98,8 @@ domains = Table('domains', metadata,
     Column('transferred_at', DateTime, default=None),
     Column('ttl', Integer, default=CONF.default_ttl, nullable=False),
     Column('serial', Integer, default=timeutils.utcnow_ts, nullable=False),
-    Column('refresh', Integer, default=CONF.default_soa_refresh,
+    # The refresh interval is randomized by _generate_soa_refresh_interval
+    Column('refresh', Integer, default=CONF.default_soa_refresh_min,
            nullable=False),
     Column('retry', Integer, default=CONF.default_soa_retry, nullable=False),
     Column('expire', Integer, default=CONF.default_soa_expire, nullable=False),
@@ -104,56 +107,74 @@ domains = Table('domains', metadata,
            nullable=False),
     Column('status', Enum(name='resource_statuses', *RESOURCE_STATUSES),
            nullable=False, server_default='PENDING', default='PENDING'),
-    Column('parent_domain_id', UUID, default=None, nullable=True),
+    Column('parent_zone_id', UUID, default=None, nullable=True),
     Column('action', Enum(name='actions', *ACTIONS),
            default='CREATE', server_default='CREATE', nullable=False),
     Column('pool_id', UUID, default=None, nullable=True),
     Column('reverse_name', String(255), nullable=False),
+    Column('delayed_notify', Boolean, default=False),
 
-    UniqueConstraint('name', 'deleted', 'pool_id', name='unique_domain_name'),
-    ForeignKeyConstraint(['parent_domain_id'],
-                         ['domains.id'],
+    UniqueConstraint('name', 'deleted', 'pool_id', name='unique_zone_name'),
+    ForeignKeyConstraint(['parent_zone_id'],
+                         ['zones.id'],
                          ondelete='SET NULL'),
 
     mysql_engine='InnoDB',
     mysql_charset='utf8',
 )
 
-domain_attributes = Table('domain_attributes', metadata,
+zone_attributes = Table('zone_attributes', metadata,
+    Column('id', UUID, default=utils.generate_uuid, primary_key=True),
+    Column('version', Integer, default=1, nullable=False),
+    Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
+    Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
+
+    Column('key', String(50)),
+    Column('value', String(255), nullable=False),
+    Column('zone_id', UUID, nullable=False),
+
+    UniqueConstraint('key', 'value', 'zone_id', name='unique_attributes'),
+    ForeignKeyConstraint(['zone_id'], ['zones.id'], ondelete='CASCADE'),
+
+    mysql_engine='InnoDB',
+    mysql_charset='utf8'
+)
+
+zone_masters = Table('zone_masters', metadata,
     Column('id', UUID(), default=utils.generate_uuid, primary_key=True),
     Column('version', Integer(), default=1, nullable=False),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
 
-    Column('key', Enum(name='key', *ZONE_ATTRIBUTE_KEYS)),
-    Column('value', String(255), nullable=False),
-    Column('domain_id', UUID(), nullable=False),
+    Column('host', String(32), nullable=False),
+    Column('port', Integer(), nullable=False),
+    Column('zone_id', UUID(), nullable=False),
 
-    UniqueConstraint('key', 'value', 'domain_id', name='unique_attributes'),
-    ForeignKeyConstraint(['domain_id'], ['domains.id'], ondelete='CASCADE'),
+    UniqueConstraint('host', 'port', 'zone_id', name='unique_masters'),
+    ForeignKeyConstraint(['zone_id'], ['zones.id'], ondelete='CASCADE'),
 
-    mysql_engine='INNODB',
+    mysql_engine='InnoDB',
     mysql_charset='utf8'
 )
 
 recordsets = Table('recordsets', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
-    Column('domain_shard', SmallInteger(), nullable=False,
-           default=lambda ctxt: default_shard(ctxt, 'domain_id')),
+    Column('zone_shard', SmallInteger, nullable=False,
+           default=lambda ctxt: default_shard(ctxt, 'zone_id')),
 
     Column('tenant_id', String(36), default=None, nullable=True),
-    Column('domain_id', UUID, nullable=False),
+    Column('zone_id', UUID, nullable=False),
     Column('name', String(255), nullable=False),
     Column('type', Enum(name='record_types', *RECORD_TYPES), nullable=False),
     Column('ttl', Integer, default=None, nullable=True),
     Column('description', Unicode(160), nullable=True),
     Column('reverse_name', String(255), nullable=False, default=''),
 
-    UniqueConstraint('domain_id', 'name', 'type', name='unique_recordset'),
-    ForeignKeyConstraint(['domain_id'], ['domains.id'], ondelete='CASCADE'),
+    UniqueConstraint('zone_id', 'name', 'type', name='unique_recordset'),
+    ForeignKeyConstraint(['zone_id'], ['zones.id'], ondelete='CASCADE'),
 
     mysql_engine='InnoDB',
     mysql_charset='utf8',
@@ -161,35 +182,35 @@ recordsets = Table('recordsets', metadata,
 
 records = Table('records', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
-    Column('domain_shard', SmallInteger(), nullable=False,
-           default=lambda ctxt: default_shard(ctxt, 'domain_id')),
+    Column('zone_shard', SmallInteger, nullable=False,
+           default=lambda ctxt: default_shard(ctxt, 'zone_id')),
 
     Column('tenant_id', String(36), default=None, nullable=True),
-    Column('domain_id', UUID, nullable=False),
+    Column('zone_id', UUID, nullable=False),
     Column('recordset_id', UUID, nullable=False),
     Column('data', Text, nullable=False),
     Column('description', Unicode(160), nullable=True),
     Column('hash', String(32), nullable=False, unique=True),
     Column('managed', Boolean, default=False),
-    Column('managed_extra', Unicode(100), default=None, nullable=True),
-    Column('managed_plugin_type', Unicode(50), default=None, nullable=True),
-    Column('managed_plugin_name', Unicode(50), default=None, nullable=True),
-    Column('managed_resource_type', Unicode(50), default=None, nullable=True),
-    Column('managed_resource_region', Unicode(100), default=None,
+    Column('managed_extra', String(100), default=None, nullable=True),
+    Column('managed_plugin_type', String(50), default=None, nullable=True),
+    Column('managed_plugin_name', String(50), default=None, nullable=True),
+    Column('managed_resource_type', String(50), default=None, nullable=True),
+    Column('managed_resource_region', String(100), default=None,
            nullable=True),
     Column('managed_resource_id', UUID, default=None, nullable=True),
-    Column('managed_tenant_id', Unicode(36), default=None, nullable=True),
+    Column('managed_tenant_id', String(36), default=None, nullable=True),
     Column('status', Enum(name='resource_statuses', *RESOURCE_STATUSES),
            server_default='PENDING', default='PENDING', nullable=False),
     Column('action', Enum(name='actions', *ACTIONS),
            default='CREATE', server_default='CREATE', nullable=False),
-    Column('serial', Integer(), server_default='1', nullable=False),
+    Column('serial', Integer, server_default='1', nullable=False),
 
     UniqueConstraint('hash', name='unique_record'),
-    ForeignKeyConstraint(['domain_id'], ['domains.id'], ondelete='CASCADE'),
+    ForeignKeyConstraint(['zone_id'], ['zones.id'], ondelete='CASCADE'),
     ForeignKeyConstraint(['recordset_id'], ['recordsets.id'],
                          ondelete='CASCADE'),
 
@@ -199,7 +220,7 @@ records = Table('records', metadata,
 
 tsigkeys = Table('tsigkeys', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
 
@@ -216,7 +237,7 @@ tsigkeys = Table('tsigkeys', metadata,
 
 blacklists = Table('blacklists', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
 
@@ -231,7 +252,7 @@ pools = Table('pools', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
 
     Column('name', String(50), nullable=False, unique=True),
     Column('description', Unicode(160), nullable=True),
@@ -241,49 +262,137 @@ pools = Table('pools', metadata,
 
     UniqueConstraint('name', name='unique_pool_name'),
 
-    mysql_engine='INNODB',
+    mysql_engine='InnoDB',
     mysql_charset='utf8'
 )
 
 pool_attributes = Table('pool_attributes', metadata,
-    Column('id', UUID(), default=utils.generate_uuid, primary_key=True),
+    Column('id', UUID, default=utils.generate_uuid, primary_key=True),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
 
     Column('key', String(255), nullable=False),
     Column('value', String(255), nullable=False),
-    Column('pool_id', UUID(), nullable=False),
+    Column('pool_id', UUID, nullable=False),
 
     ForeignKeyConstraint(['pool_id'], ['pools.id'], ondelete='CASCADE'),
 
-    mysql_engine='INNODB',
+    mysql_engine='InnoDB',
     mysql_charset='utf8'
 )
 
 pool_ns_records = Table('pool_ns_records', metadata,
-    Column('id', UUID(), default=utils.generate_uuid, primary_key=True),
+    Column('id', UUID, default=utils.generate_uuid, primary_key=True),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
 
-    Column('pool_id', UUID(), nullable=False),
-    Column('priority', Integer(), nullable=False),
+    Column('pool_id', UUID, nullable=False),
+    Column('priority', Integer, nullable=False),
     Column('hostname', String(255), nullable=False),
 
     ForeignKeyConstraint(['pool_id'], ['pools.id'], ondelete='CASCADE'),
     UniqueConstraint('pool_id', 'hostname', name='unique_ns_name'),
 
-    mysql_engine='INNODB',
+    mysql_engine='InnoDB',
     mysql_charset='utf8')
 
-zone_transfer_requests = Table('zone_transfer_requests', metadata,
+pool_nameservers = Table('pool_nameservers', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
     Column('version', Integer(), default=1, nullable=False),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
 
-    Column('domain_id', UUID, nullable=False),
+    Column('pool_id', UUID(), nullable=False),
+    Column('host', String(255), nullable=False),
+    Column('port', Integer(), nullable=False),
+
+    ForeignKeyConstraint(['pool_id'], ['pools.id'], ondelete='CASCADE'),
+    UniqueConstraint('pool_id', 'host', 'port', name='unique_pool_host_port'),
+
+    mysql_engine='InnoDB',
+    mysql_charset='utf8',
+)
+
+pool_targets = Table('pool_targets', metadata,
+    Column('id', UUID, default=utils.generate_uuid, primary_key=True),
+    Column('version', Integer(), default=1, nullable=False),
+    Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
+    Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
+
+    Column('pool_id', UUID(), nullable=False),
+    Column('type', String(50), nullable=False),
+    Column('tsigkey_id', UUID(), nullable=True),
+    Column('description', Unicode(160), nullable=True),
+
+    ForeignKeyConstraint(['pool_id'], ['pools.id'], ondelete='CASCADE'),
+
+    mysql_engine='InnoDB',
+    mysql_charset='utf8',
+)
+
+pool_target_masters = Table('pool_target_masters', metadata,
+    Column('id', UUID, default=utils.generate_uuid, primary_key=True),
+    Column('version', Integer(), default=1, nullable=False),
+    Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
+    Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
+
+    Column('pool_target_id', UUID(), nullable=False),
+    Column('host', String(255), nullable=False),
+    Column('port', Integer(), nullable=False),
+
+    ForeignKeyConstraint(['pool_target_id'], ['pool_targets.id'],
+                         ondelete='CASCADE'),
+    UniqueConstraint('pool_target_id', 'host', 'port',
+                     name='unique_pool_target_host_port'),
+
+    mysql_engine='InnoDB',
+    mysql_charset='utf8',
+)
+
+pool_target_options = Table('pool_target_options', metadata,
+    Column('id', UUID, default=utils.generate_uuid, primary_key=True),
+    Column('version', Integer(), default=1, nullable=False),
+    Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
+    Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
+
+    Column('pool_target_id', UUID(), nullable=False),
+    Column('key', String(255), nullable=False),
+    Column('value', String(255), nullable=False),
+
+    ForeignKeyConstraint(['pool_target_id'], ['pool_targets.id'],
+                         ondelete='CASCADE'),
+    UniqueConstraint('pool_target_id', 'key', name='unique_pool_target_key'),
+
+    mysql_engine='InnoDB',
+    mysql_charset='utf8',
+)
+
+pool_also_notifies = Table('pool_also_notifies', metadata,
+    Column('id', UUID, default=utils.generate_uuid, primary_key=True),
+    Column('version', Integer(), default=1, nullable=False),
+    Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
+    Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
+
+    Column('pool_id', UUID(), nullable=False),
+    Column('host', String(255), nullable=False),
+    Column('port', Integer(), nullable=False),
+
+    ForeignKeyConstraint(['pool_id'], ['pools.id'], ondelete='CASCADE'),
+    UniqueConstraint('pool_id', 'host', 'port', name='unique_pool_host_port'),
+
+    mysql_engine='InnoDB',
+    mysql_charset='utf8',
+)
+
+zone_transfer_requests = Table('zone_transfer_requests', metadata,
+    Column('id', UUID, default=utils.generate_uuid, primary_key=True),
+    Column('version', Integer, default=1, nullable=False),
+    Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
+    Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
+
+    Column('zone_id', UUID, nullable=False),
     Column("key", String(255), nullable=False),
     Column("description", String(255), nullable=False),
     Column("tenant_id", String(36), default=None, nullable=False),
@@ -292,7 +401,7 @@ zone_transfer_requests = Table('zone_transfer_requests', metadata,
            nullable=False, server_default='ACTIVE',
            default='ACTIVE'),
 
-    ForeignKeyConstraint(['domain_id'], ['domains.id'], ondelete='CASCADE'),
+    ForeignKeyConstraint(['zone_id'], ['zones.id'], ondelete='CASCADE'),
 
     mysql_engine='InnoDB',
     mysql_charset='utf8',
@@ -300,18 +409,18 @@ zone_transfer_requests = Table('zone_transfer_requests', metadata,
 
 zone_transfer_accepts = Table('zone_transfer_accepts', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
 
-    Column('domain_id', UUID, nullable=False),
+    Column('zone_id', UUID, nullable=False),
     Column('zone_transfer_request_id', UUID, nullable=False),
     Column("tenant_id", String(36), default=None, nullable=False),
     Column("status", Enum(name='resource_statuses', *TASK_STATUSES),
            nullable=False, server_default='ACTIVE',
            default='ACTIVE'),
 
-    ForeignKeyConstraint(['domain_id'], ['domains.id'], ondelete='CASCADE'),
+    ForeignKeyConstraint(['zone_id'], ['zones.id'], ondelete='CASCADE'),
     ForeignKeyConstraint(
         ['zone_transfer_request_id'],
         ['zone_transfer_requests.id'],
@@ -322,13 +431,13 @@ zone_transfer_accepts = Table('zone_transfer_accepts', metadata,
 )
 
 zone_tasks = Table('zone_tasks', metadata,
-    Column('id', UUID(), default=utils.generate_uuid, primary_key=True),
+    Column('id', UUID, default=utils.generate_uuid, primary_key=True),
     Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
     Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
-    Column('version', Integer(), default=1, nullable=False),
+    Column('version', Integer, default=1, nullable=False),
     Column('tenant_id', String(36), default=None, nullable=True),
 
-    Column('domain_id', UUID(), nullable=True),
+    Column('zone_id', UUID, nullable=True),
     Column('task_type', Enum(name='task_types', *ZONE_TASK_TYPES),
            nullable=True),
     Column('message', String(160), nullable=True),
@@ -337,5 +446,5 @@ zone_tasks = Table('zone_tasks', metadata,
            default='ACTIVE'),
     Column('location', String(160), nullable=True),
 
-    mysql_engine='INNODB',
+    mysql_engine='InnoDB',
     mysql_charset='utf8')
