@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -149,8 +149,8 @@ class SchemaFormatTest(TestCase):
         for hostname in invalid_hostnames:
             self.assertFalse(format.is_hostname(hostname))
 
-    def test_is_domainname(self):
-        valid_domainnames = [
+    def test_is_ns_hostname(self):
+        valid_ns_hostnames = [
             'example.com.',
             'www.example.com.',
             '12345.example.com.',
@@ -171,7 +171,77 @@ class SchemaFormatTest(TestCase):
              'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghi.'),
         ]
 
-        invalid_domainnames = [
+        invalid_ns_hostnames = [
+            # Wildcard NS hostname, bug #1533299
+            '*.example.com.',
+            '**.example.com.',
+            '*.*.example.org.',
+            'a.*.example.org.',
+            # Exceeds single lable length limit
+            ('abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijkL'
+             '.'),
+            ('abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.'
+             'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.'
+             'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.'
+             'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijkL'
+             '.'),
+            # Exceeds total length limit
+            ('abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.'
+             'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.'
+             'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.'
+             'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.'
+             'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopq.'),
+            # Empty label part
+            'abc..def.',
+            '..',
+            # Invalid character
+            'abc$.def.',
+            'abc.def$.',
+            # Labels must not start with a -
+            '-abc.',
+            'abc.-def.',
+            'abc.-def.ghi.',
+            # Labels must not end with a -
+            'abc-.',
+            'abc.def-.',
+            'abc.def-.ghi.',
+            # Labels must not start or end with a -
+            '-abc-.',
+            'abc.-def-.',
+            'abc.-def-.ghi.',
+            # Trailing newline - Bug 1471158
+            "www.example.com.\n",
+        ]
+
+        for hostname in valid_ns_hostnames:
+            self.assertTrue(format.is_ns_hostname(hostname))
+
+        for hostname in invalid_ns_hostnames:
+            self.assertFalse(format.is_ns_hostname(hostname))
+
+    def test_is_zonename(self):
+        valid_zonenames = [
+            'example.com.',
+            'www.example.com.',
+            '12345.example.com.',
+            '192-0-2-1.example.com.',
+            'ip192-0-2-1.example.com.',
+            'www.ip192-0-2-1.example.com.',
+            'ip192-0-2-1.www.example.com.',
+            'abc-123.example.com.',
+            '_tcp.example.com.',
+            '_service._tcp.example.com.',
+            ('1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.8.b.d.0.1.0.0.2'
+             '.ip6.arpa.'),
+            '1.1.1.1.in-addr.arpa.',
+            'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.',
+            ('abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.'
+             'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.'
+             'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.'
+             'abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghi.'),
+        ]
+
+        invalid_zonenames = [
             '*.example.com.',
             '**.example.com.',
             '*.*.example.org.',
@@ -215,11 +285,11 @@ class SchemaFormatTest(TestCase):
             "example.com.\n",
         ]
 
-        for domainname in valid_domainnames:
-            self.assertTrue(format.is_domainname(domainname), domainname)
+        for zonename in valid_zonenames:
+            self.assertTrue(format.is_zonename(zonename), zonename)
 
-        for domainname in invalid_domainnames:
-            self.assertFalse(format.is_domainname(domainname), domainname)
+        for zonename in invalid_zonenames:
+            self.assertFalse(format.is_zonename(zonename), zonename)
 
     def test_is_srv_hostname(self):
         valid_hostnames = [
@@ -332,11 +402,11 @@ class SchemaFormatTest(TestCase):
         ]
 
         for sshfp in valid_sshfps:
-            self.assertTrue(format.is_sshfp(sshfp),
+            self.assertTrue(format.is_sshfp_fingerprint(sshfp),
                             'Expected Valid: %s' % sshfp)
 
         for sshfp in invalid_sshfps:
-            self.assertFalse(format.is_sshfp(sshfp),
+            self.assertFalse(format.is_sshfp_fingerprint(sshfp),
                              'Expected Invalid: %s' % sshfp)
 
     def test_is_uuid(self):
