@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,6 +14,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+"""
+Test API middleware
+"""
+
+import fixtures
 import oslotest.base
 import mock
 
@@ -46,11 +51,10 @@ class KeystoneContextMiddlewareTest(oslotest.base.BaseTestCase):
 
         # Replace the DesignateContext class..
         self.ctxt = mock.Mock()
-        ctxt_patcher = mock.patch(
+        self.useFixture(fixtures.MockPatch(
             'designate.context.DesignateContext',
-            return_value=self.ctxt)
-        self.addCleanup(ctxt_patcher.stop)
-        ctxt_patcher.start()
+            return_value=self.ctxt
+        ))
 
     def test_sudo_by_project_id(self):
         self.request.headers.update({
@@ -90,8 +94,8 @@ class KeystoneContextMiddlewareTest(oslotest.base.BaseTestCase):
 
         self.app(self.request)
 
-        self.assertFalse('all_tenants' in self.request.params)
-        self.assertEqual(self.ctxt.all_tenants, True)
+        self.assertNotIn('all_tenants', self.request.params)
+        self.assertTrue(self.ctxt.all_tenants)
 
     def test_all_tenants_in_params(self):
         self.request.headers.update({
@@ -102,8 +106,8 @@ class KeystoneContextMiddlewareTest(oslotest.base.BaseTestCase):
 
         self.app(self.request)
 
-        self.assertFalse('all_tenants' in self.request.params)
-        self.assertEqual(self.ctxt.all_tenants, True)
+        self.assertNotIn('all_tenants', self.request.params)
+        self.assertTrue(self.ctxt.all_tenants)
 
     def test_all_tenants_not_set(self):
         self.request.headers.update({
@@ -123,7 +127,7 @@ class KeystoneContextMiddlewareTest(oslotest.base.BaseTestCase):
 
         self.app(self.request)
 
-        self.assertFalse('edit_managed_records' in self.request.params)
+        self.assertNotIn('edit_managed_records', self.request.params)
         self.assertTrue(self.ctxt.edit_managed_records)
 
     def test_edit_managed_records_in_headers(self):
@@ -159,21 +163,21 @@ class SSLMiddlewareTest(oslotest.base.BaseTestCase):
         self.request.environ['HTTP_X_FORWARDED_PROTO'] = 'poo'
         self.app(self.request)
 
-        self.assertEqual(self.request.environ['wsgi.url_scheme'], 'poo')
+        self.assertEqual('poo', self.request.environ['wsgi.url_scheme'])
 
     def test_http_header(self):
         self.request.environ['wsgi.url_scheme'] = ''
         self.request.environ['HTTP_X_FORWARDED_PROTO'] = 'http'
         self.app(self.request)
 
-        self.assertEqual(self.request.environ['wsgi.url_scheme'], 'http')
+        self.assertEqual('http', self.request.environ['wsgi.url_scheme'])
 
     def test_https_header(self):
         self.request.environ['wsgi.url_scheme'] = 'http'
         self.request.environ['HTTP_X_FORWARDED_PROTO'] = 'https'
         self.app(self.request)
 
-        self.assertEqual(self.request.environ['wsgi.url_scheme'], 'https')
+        self.assertEqual('https', self.request.environ['wsgi.url_scheme'])
 
     def test_override_proto(self):
         self.request.environ['wsgi.url_scheme'] = 'http'
@@ -182,4 +186,4 @@ class SSLMiddlewareTest(oslotest.base.BaseTestCase):
 
         self.app(self.request)
 
-        self.assertEqual(self.request.environ['wsgi.url_scheme'], 'poo')
+        self.assertEqual('poo', self.request.environ['wsgi.url_scheme'])
