@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -40,14 +40,19 @@ class Service(service.RPCService, coordination.CoordinationMixin,
 
     target = messaging.Target(version=RPC_API_VERSION)
 
-    def __init__(self, threads=None):
-        super(Service, self).__init__(threads=threads)
+    @property
+    def storage(self):
+        if not hasattr(self, '_storage'):
+            storage_driver = cfg.CONF['service:zone_manager'].storage_driver
+            self._storage = storage.get_storage(storage_driver)
+        return self._storage
 
-        storage_driver = cfg.CONF['service:zone_manager'].storage_driver
-        self.storage = storage.get_storage(storage_driver)
-
-        # Get a quota manager instance
-        self.quota = quota.get_quota()
+    @property
+    def quota(self):
+        if not hasattr(self, '_quota'):
+            # Get a quota manager instance
+            self._quota = quota.get_quota()
+        return self._quota
 
     @property
     def service_name(self):
@@ -69,7 +74,7 @@ class Service(service.RPCService, coordination.CoordinationMixin,
 
         enabled = CONF['service:zone_manager'].enabled_tasks
         for task in tasks.PeriodicTask.get_extensions(enabled):
-            LOG.debug("Registering task %s" % task)
+            LOG.debug("Registering task %s", task)
 
             # Instantiate the task
             task = task()
@@ -81,14 +86,14 @@ class Service(service.RPCService, coordination.CoordinationMixin,
             self.tg.add_timer(interval, task)
 
     def _rebalance(self, my_partitions, members, event):
-        LOG.info(_LI("Received rebalance event %s") % event)
+        LOG.info(_LI("Received rebalance event %s"), event)
         self.partition_range = my_partitions
 
     # Begin RPC Implementation
 
     # Zone Export
-    def start_zone_export(self, context, domain, export):
-        criterion = {'domain_id': domain.id}
+    def start_zone_export(self, context, zone, export):
+        criterion = {'zone_id': zone.id}
         count = self.storage.count_recordsets(context, criterion)
 
         export = self._determine_export_method(context, export, count)
@@ -139,11 +144,11 @@ class Service(service.RPCService, coordination.CoordinationMixin,
         return export
 
     def _export_zone(self, context, zone_id):
-        domain = self.central_api.get_domain(context, zone_id)
+        zone = self.central_api.get_zone(context, zone_id)
 
-        criterion = {'domain_id': zone_id}
+        criterion = {'zone_id': zone_id}
         recordsets = self.storage.find_recordsets_export(context, criterion)
 
         return utils.render_template('export-zone.jinja2',
-                                     domain=domain,
+                                     zone=zone,
                                      recordsets=recordsets)
